use Test::More tests => 16;
use lib 'lib';
use Art::World;
use Art::World::Util;

my $munnies = 9999;

my $collector1 = Art::World
  ->new_collector(
    name => Art::World::Util->new_person->fake_name,
    money => $munnies,
    id => 3
  );

my $collector2 = Art::World
  ->new_collector(
    name => Art::World::Util->new_person->fake_name,
    money => $munnies + 1000,
    id => 4
  );

my $homogenic_artist = Art::World->new_artist(
  name => Art::World::Util->new_person->fake_name,
  collectors => [ $collector1, $collector2 ]
);

ok $homogenic_artist->is_homogenic, 'Artist status is homogenic since it has collectors';

my $artwork = Art::World->new_artwork(
    creator => [ $homogenic_artist ]  ,
    value => 10_000,
    owner => [ $collector1, $collector2 ]
  );

my $artwork2 = Art::World->new_artwork(
  creator => [ $homogenic_artist ]  ,
  value => 12_000,
  owner => [ $collector2 ]
);

my $artwork3 = Art::World->new_artwork(
  creator => [ $homogenic_artist ]  ,
  value => 12_000
 );

is $homogenic_artist->name, $artwork3->owner->[0]->name, "Default owner of an artwork is it's creator";

$munnies = 100_000;

my $collector = Art::World
  ->new_collector(
    name => Art::World::Util->new_person->fake_name,
    money => $munnies,
    id => 3
  );

isa_ok $collector, 'Art::World::Agent';
can_ok $collector, qw/acquire participate pay/;

ok $collector->money, 'Collector got a money attr';
ok $collector->collection, 'Collector got a collection attr';

is $collector->money, $munnies, 'Collector money value is valid';

ok $collector->does('Art::World::Buyer'), 'Collector does role Buyer';

ok $collector->acquire( $artwork ),
  'Collector added an artwork to their collection';

# TODO test that each owner received the correct amount of money (their own part => value of the artwork / artwork total price)

ok $collector->acquire( $artwork2 ),
  'Collector added a second artwork to their collection';

is $collector->money, 78_000, 'Check collector\'s fortune';

foreach (@{ $collector->collection })  {
  isa_ok $_, 'Art::World::Artwork';
}

is scalar @{ $collector->collection }, 2, 'Checked length of collector\'s collection';

# Owner change
my $seller_name = $artwork3->owner->[0]->name;
$collector->acquire( $artwork3 );
my $buyer_name = $artwork3->owner->[0]->name;

# TODO test that the artist received the correct amount of money (100%)
# TODO check that the new owner money is not only stored in the artwork object

isnt $seller_name, $buyer_name, 'Artwork owner changed';

is scalar @{ $collector->collection }, 3, 'Length of collector\'s collection increased';

done_testing();
